@@ -1,9 +1,13 @@
-import keras_cv
-from luketils import utils
-from luketils import drawing
-from luketils.visualization.plot_gallery import plot_gallery
 import functools
 
+import keras_cv
+import numpy as np
+from matplotlib import patches
+
+from luketils import drawing
+from luketils import utils
+from luketils.visualization.plot_gallery import plot_gallery
+
 
 def plot_bounding_box_gallery(
     images,
@@ -17,6 +21,10 @@ def plot_bounding_box_gallery(
     font_scale=1.0,
     text_thickness=None,
     class_mapping=None,
+    ground_truth_mapping=None,
+    prediction_mapping=None,
+    legend=False,
+    legend_handles=None,
     **kwargs
 ):
     """plots a gallery of images with corresponding bounding box annotations
@@ -36,12 +44,21 @@ def plot_bounding_box_gallery(
         true_color: three element tuple representing the color to use for plotting
             true bounding boxes.
         class_mapping: (Optional) class mapping from class IDs to strings
+        ground_truth_mapping:  (Optional) class mapping from class IDs to strings,
+            defaults to `class_mapping`
+        prediction_mapping:  (Optional) class mapping from class IDs to strings,
+            defaults to `class_mapping`
         thickness: (Optional) thickness for the box and text labels.  Defaults to 2.
         text_thickness: (Optional) the thickness for the text, defaults to `1.0`.
         font_scale: (Optional) font size to draw bounding boxes in.
+        legend: Whether or not to create a legend with the specified colors for `y_true`
+            and `y_pred`.  Defaults to False.
         kwargs: keyword arguments to propagate to
             `keras_cv.visualization.gallery_show()`.
     """
+    prediction_mapping = prediction_mapping or class_mapping
+    ground_truth_mapping = ground_truth_mapping or class_mapping
+
     images = utils.to_numpy(images)
     y_true = utils.to_numpy(y_true)
     y_pred = utils.to_numpy(y_pred)
@@ -51,7 +68,6 @@ def plot_bounding_box_gallery(
     draw_fn = functools.partial(
         drawing.draw_bounding_boxes,
         bounding_box_format=bounding_box_format,
-        class_mapping=class_mapping,
         thickness=thickness,
         text_thickness=text_thickness,
         font_scale=font_scale,
@@ -59,16 +75,23 @@ def plot_bounding_box_gallery(
 
     if y_true is not None:
         plotted_images = draw_fn(
-            plotted_images,
-            y_true,
-            true_color,
-        )
-    
-    if y_pred is not None:
-        plotted_images = draw_fn(
-            plotted_images,
-            y_pred,
-            pred_color,
+            plotted_images, y_true, true_color, class_mapping=ground_truth_mapping
         )
 
-    plot_gallery(plotted_images, value_range, **kwargs)
+    if y_pred is not None:
+        plotted_images = draw_fn(
+            plotted_images, y_pred, pred_color, class_mapping=prediction_mapping
+        )
+
+    if legend:
+        if legend_handles:
+            raise ValueError(
+                "Only pass `legend` OR `legend_handles` to "
+                "`luketils.visualization.plot_bounding_box_gallery()`."
+            )
+        legend_handles = [
+            patches.Patch(color=np.array(true_color) / 255.0, label="Ground Truth"),
+            patches.Patch(color=np.array(pred_color) / 255.0, label="Prediction"),
+        ]
+
+    plot_gallery(plotted_images, value_range, legend_handles=legend_handles, **kwargs)
